@@ -21,6 +21,7 @@ use crate::utils::string_util::to_snake_name;
 use crate::wrapper::Wrapper;
 use std::marker::PhantomData;
 use std::ops::{Deref, DerefMut};
+use serde_json::value::Value::Null;
 
 /// DataBase Table Model trait
 ///
@@ -101,6 +102,7 @@ pub trait CRUDTable: Send + Sync + Serialize + DeserializeOwned {
         &self,
         db_type: &DriverType,
         index: &mut usize,
+        skips: &[Skip],
     ) -> Result<(String, String, Vec<serde_json::Value>)> {
         let mut value_sql = String::new();
         let mut arr = vec![];
@@ -117,8 +119,37 @@ pub trait CRUDTable: Send + Sync + Serialize + DeserializeOwned {
         }
         let mut column_sql = String::new();
         for column in columns {
+            let mut do_continue = false;
             let column = crate::utils::string_util::un_packing_string(column);
+            for x in skips {
+                match x {
+                    Skip::Column(skip_column) => {
+                        if column.eq(*skip_column) {
+                            do_continue = true;
+                            break;
+                        }
+                    }
+                    _ => {}
+                }
+            }
+            if do_continue {
+                continue;
+            }
             let v = map.get(column).unwrap_or(&serde_json::Value::Null);
+            for x in skips {
+                match x {
+                    Skip::Value(skip_value) => {
+                        if v.eq(skip_value) {
+                            do_continue = true;
+                            break;
+                        }
+                    }
+                    _ => {}
+                }
+            }
+            if do_continue {
+                continue;
+            }
             //cast convert
             column_sql = column_sql + column + ",";
             let mut data = String::new();
@@ -179,13 +210,14 @@ impl<T> CRUDTable for Option<T>
         &self,
         db_type: &DriverType,
         index: &mut usize,
+        skips: &[Skip],
     ) -> Result<(String, String, Vec<serde_json::Value>)> {
         if self.is_none() {
             return Err(crate::core::Error::from(
                 "[rbatis] can not make_sql_arg() for None value!",
             ));
         }
-        T::make_value_sql_arg(self.as_ref().unwrap(), db_type, index)
+        T::make_value_sql_arg(self.as_ref().unwrap(), db_type, index, skips)
     }
 }
 
@@ -219,15 +251,16 @@ pub trait CRUD {
         &self,
         table: &T,
         w: &Wrapper,
+        skips: &[Skip],
     ) -> Result<DBExecResult>
         where
             T: CRUDTable;
 
-    async fn save<T>(&self, table: &T) -> Result<DBExecResult>
+    async fn save<T>(&self, table: &T, skips: &[Skip]) -> Result<DBExecResult>
         where
             T: CRUDTable;
 
-    async fn save_batch<T>(&self, tables: &[T]) -> Result<DBExecResult>
+    async fn save_batch<T>(&self, tables: &[T], skips: &[Skip]) -> Result<DBExecResult>
         where
             T: CRUDTable;
 
@@ -237,6 +270,7 @@ pub trait CRUD {
         &self,
         tables: &[T],
         slice_len: usize,
+        skips: &[Skip],
     ) -> Result<DBExecResult>
         where
             T: CRUDTable;
@@ -332,6 +366,7 @@ pub trait CRUDMut: ExecutorMut {
         &mut self,
         table: &T,
         w: &Wrapper,
+        skips: &[Skip],
     ) -> Result<DBExecResult>
         where
             T: CRUDTable,
@@ -341,7 +376,7 @@ pub trait CRUDMut: ExecutorMut {
         } else {
             let mut w = w.clone();
             let mut index = 0;
-            let (columns, column_values, args) = table.make_value_sql_arg(&self.driver_type()?, &mut index)?;
+            let (columns, column_values, args) = table.make_value_sql_arg(&self.driver_type()?, &mut index, skips)?;
             let table_name = choose_dyn_table_name::<T>(&w);
             w = w.insert_into(&table_name, &columns, &column_values);
             for x in args {
@@ -352,13 +387,13 @@ pub trait CRUDMut: ExecutorMut {
     }
 
     /// save one entity to database
-    async fn save<T>(&mut self, table: &T) -> Result<DBExecResult>
+    async fn save<T>(&mut self, table: &T, skips: &[Skip]) -> Result<DBExecResult>
         where
             T: CRUDTable,
     {
         let mut index = 0;
         let (columns, values, args) =
-            table.make_value_sql_arg(&self.driver_type()?, &mut index)?;
+            table.make_value_sql_arg(&self.driver_type()?, &mut index, skips)?;
         let sql = format!(
             "{} {} ({}) {} ({})",
             crate::sql::TEMPLATE.insert_into.value,
@@ -377,7 +412,7 @@ pub trait CRUDMut: ExecutorMut {
     /// [rbatis] Exec ==>   insert into biz_activity (id,name,version) values ( ? , ? , ?),( ? , ? , ?)
     ///
     ///
-    async fn save_batch<T>(&mut self, tables: &[T]) -> Result<DBExecResult>
+    async fn save_batch<T>(&mut self, tables: &[T], skips: &[Skip]) -> Result<DBExecResult>
         where
             T: CRUDTable,
     {
@@ -393,7 +428,7 @@ pub trait CRUDMut: ExecutorMut {
         let mut field_index = 0;
         for x in tables {
             let (columns, values, args) =
-                x.make_value_sql_arg(&self.driver_type()?, &mut field_index)?;
+                x.make_value_sql_arg(&self.driver_type()?, &mut field_index, skips)?;
             if column_sql.is_empty() {
                 column_sql = columns;
             }
@@ -426,12 +461,13 @@ pub trait CRUDMut: ExecutorMut {
         &mut self,
         tables: &[T],
         slice_len: usize,
+        skips: &[Skip],
     ) -> Result<DBExecResult>
         where
             T: CRUDTable,
     {
         if slice_len == 0 || tables.len() <= slice_len {
-            return self.save_batch(tables).await;
+            return self.save_batch(tables, skips).await;
         } else {
             let mut temp_result = DBExecResult {
                 rows_affected: 0,
@@ -448,7 +484,7 @@ pub trait CRUDMut: ExecutorMut {
                     temp_len = total;
                 }
                 let temp = &tables[page * slice_len..temp_len];
-                let result = self.save_batch(temp).await?;
+                let result = self.save_batch(temp, skips).await?;
                 temp_result.last_insert_id = result.last_insert_id;
                 temp_result.rows_affected = result.rows_affected + temp_result.rows_affected;
             }
@@ -703,7 +739,7 @@ pub trait CRUDMut: ExecutorMut {
             &rb
                 .new_wrapper_table::<T>()
                 .eq(column, value),
-            &[Skip::Value(&Value::Null), Skip::Column("id"), Skip::Column(column)],
+            &[Skip::Value(Value::Null), Skip::Column("id"), Skip::Column(column)],
         )
             .await
     }
@@ -868,28 +904,28 @@ fn make_select_sql<T>(rb: &Rbatis, column: &str, w: &Wrapper) -> Result<String>
 
 #[async_trait]
 impl CRUD for Rbatis {
-    async fn save_by_wrapper<T>(&self, table: &T, w: &Wrapper) -> Result<DBExecResult> where
+    async fn save_by_wrapper<T>(&self, table: &T, w: &Wrapper, skips: &[Skip]) -> Result<DBExecResult> where
         T: CRUDTable {
         let mut conn = self.acquire().await?;
-        conn.save_by_wrapper(table, w).await
+        conn.save_by_wrapper(table, w, skips).await
     }
 
-    async fn save<T>(&self, table: &T) -> Result<DBExecResult> where
+    async fn save<T>(&self, table: &T, skips: &[Skip]) -> Result<DBExecResult> where
         T: CRUDTable {
         let mut conn = self.acquire().await?;
-        conn.save(table).await
+        conn.save(table, skips).await
     }
 
-    async fn save_batch<T>(&self, tables: &[T]) -> Result<DBExecResult> where
+    async fn save_batch<T>(&self, tables: &[T], skips: &[Skip]) -> Result<DBExecResult> where
         T: CRUDTable {
         let mut conn = self.acquire().await?;
-        conn.save_batch(tables).await
+        conn.save_batch(tables, skips).await
     }
 
-    async fn save_batch_slice<T>(&self, tables: &[T], slice_len: usize) -> Result<DBExecResult> where
+    async fn save_batch_slice<T>(&self, tables: &[T], slice_len: usize, skips: &[Skip]) -> Result<DBExecResult> where
         T: CRUDTable {
         let mut conn = self.acquire().await?;
-        conn.save_batch_slice(tables, slice_len).await
+        conn.save_batch_slice(tables, slice_len, skips).await
     }
 
     async fn remove_by_wrapper<T>(&self, w: &Wrapper) -> Result<u64> where
@@ -991,12 +1027,19 @@ impl CRUD for Rbatis {
 }
 
 
-/// choose skip type
+/// skip column or param value
 pub enum Skip<'a> {
     ///skip column
     Column(&'a str),
     ///skip serde json value ref
-    Value(&'a serde_json::Value),
+    Value(serde_json::Value),
+}
+
+impl<'a> Skip<'a> {
+    /// from serialize value
+    pub fn value<T>(arg: T) -> Self where T: Serialize {
+        Self::Value(serde_json::json!(arg))
+    }
 }
 
 
@@ -1065,8 +1108,9 @@ impl<T, P> CRUDTable for DynTableColumn<T, P> where T: CRUDTable, P: TableColumn
         &self,
         db_type: &DriverType,
         index: &mut usize,
+        skips: &[Skip],
     ) -> Result<(String, String, Vec<serde_json::Value>)> {
-        T::make_value_sql_arg(self, db_type, index)
+        T::make_value_sql_arg(self, db_type, index, skips)
     }
 
     /// return cast chain
